# -*- coding: utf-8 -*-
import django

from django.contrib.admin.views.main import SEARCH_VAR
from django.utils.translation import gettext as _
from django.template import Library
from django.utils.safestring import mark_safe

if django.VERSION < (3, 2):
    from django.forms.forms import BoundField
else:
    from django.forms.boundfield import BoundField

register = Library()


@register.inclusion_tag("filters/advanced_search_form.html", takes_context=True)
def advanced_search_form(context, cl):

    request = context['request']
    search_form = None
    display_fields = None

    if hasattr(cl.model_admin, 'search_filterset'):
        search_form = cl.model_admin.search_filterset.form
        display_fields = cl.model_admin.search_filterset.Meta.advanced_search_fields

    return {
        'search_form': search_form,
        'search_or_filters': (getattr(cl, 'search_fields', None) or cl.has_filters),
        'display_fields': display_fields
    }


@register.simple_tag
def search_form_row(search_form, name):
    name2 = "".join(name.split(":")[:-1]) if ":" in name else name
    if name2.endswith('__exact') and name2 not in search_form.fields:
        # this handles the case you use eg: title__exact in advanced_search_fields
        field = search_form.fields[name2.replace('__exact', '')]
    else:
        field = search_form.fields[name2]
    bf = BoundField(search_form, field, name2)
    return mark_safe("<td>%s</td><td>%s</td>" % (_(bf.label), bf))


@register.inclusion_tag('filters/search_form.html')
def jsearch_form(cl):
    """
    Displays a search form for searching the list.
    """
    return {
        # the search toolbar is shown if some filter is available
        'show_filters': (getattr(cl, 'search_fields', None) or
                         hasattr(cl.model_admin, 'search_form') or
                         cl.has_filters),
        'advanced_search': hasattr(cl.model_admin, 'search_form'),
        'cl': cl,
        'show_result_count': cl.result_count != cl.full_result_count,
        'search_var': SEARCH_VAR
    }
